@@ -10,7 +10,7 @@ use Template::Timer;
 use MRO::Compat;
 use Scalar::Util qw/blessed weaken/;
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 $VERSION = eval $VERSION;
 
 __PACKAGE__->mk_accessors('template');
@@ -537,24 +537,7 @@ The output generated by the template is stored in C<< $c->response->body >>.
 
 If you wish to use the output of a template for some other purpose than
 displaying in the response, e.g. for sending an email, this is possible using
-L<Catalyst::Plugin::Email> and the L<render> method:
-
-  sub send_email : Local {
-    my ($self, $c) = @_;
-
-    $c->email(
-      header => [
-        To      => 'me@localhost',
-        Subject => 'A TT Email',
-      ],
-      body => $c->view('Web')->render($c, 'email.tt', {
-        additional_template_paths => [ $c->config->{root} . '/email_templates'],
-        email_tmpl_param1 => 'foo'
-        }
-      ),
-    );
-  # Redirect or display a message
-  }
+other views, such as L<Catalyst::View::Email::Template>.
 
 =head2 TEMPLATE PROFILING
 
